@@ -16,8 +16,7 @@ import json
 from oauth2client import file, client, tools
 
 # Load logging before anything else
-logging.basicConfig(format='>> %(message)s')
-logr = logging.getLogger('members')
+logr = logging.getLogger('df2gspread')
 
 ''' Load the file with credentials '''
 CLIENT_SECRET_FILE = os.path.join( os.path.expanduser("~"), ".gdrive_private")
